@@ -14,7 +14,7 @@
 #' @param conf.int Numeric. Confidence level for confidence intervals.
 #' @inheritParams emmeans::summary.emmGrid
 #' @inheritParams glue_apa_results
-#' @inheritDotParams apa_num
+#' @inheritDotParams apa_num.numeric
 #' @details
 #'
 #' When p-values and confidence intervals are adjusted for multiple testing,
@@ -167,7 +167,7 @@ apa_print.summary_emm <- function(
     stat_colnames <- c("statistic", df_colname, p_value)
   }
 
-  # Assamble table
+  # Assemble table
 
   ## Add split variables
   split_by <- attr(x, "by.vars") # lsmeans
@@ -257,28 +257,20 @@ apa_print.summary_emm <- function(
   ## Add contrast names
   # rownames(tidy_x) <- if(!is.null(contrast_names)) contrast_names else tidy_x$contrast
   # tidy_x <- tidy_x[, which(colnames(tidy_x) != "contrast")]
+
   if(length(factors) > 1) {
     contrast_row_names <- apply(
       tidy_x[, c(factors[which(factors != "contrast")], factors[which(factors == "contrast")])]
-      , 1
-      , paste
+      , MARGIN = 1L
+      , FUN = paste
       , collapse = "_"
     )
   } else if(length(factors) == 1) {
-    contrast_row_names <- tidy_x[, factors]
+    contrast_row_names <- tidy_x[, factors, drop = TRUE]
   } else {
     stop("Could not determine names to address each result by.")
   }
-
-  rownames(tidy_x) <- sanitize_terms(
-    gsub( # Leading or double underscores from simple contrasts where there are dots in some columns that are replaced by ""
-      "^\\_|\\_(\\_)", "\\1"
-      , gsub(
-        " |\\.", ""
-        , gsub("\\.0+$", "", contrast_row_names) # Removes trailing zero-digits for numeric predictors
-      )
-    )
-  )
+  terms_sanitized <- sanitize_terms(contrast_row_names)
 
   ## Mark test families (see below)
   if(!is.null(attr(x, "famSize"))) {
@@ -336,7 +328,7 @@ apa_print.summary_emm <- function(
     , est_glue = est_glue(tidy_x)
     , stat_glue = stat_glue(tidy_x)
     , in_paren = in_paren
-    , term_names = make.names(rownames(tidy_x))
+    , term_names = make.names(terms_sanitized)
   )
 
   ## Mark test families
